==> tuia-advert-center-api-1.5.9-20180814.071018-48-sources.jar: cn/com/duiba/tuia/core/api/dto/req/ReqPromoteTestAuditQuery.java <==
package cn.com.duiba.tuia.core.api.dto.req;


import java.util.Date;
import java.util.List;

/**查询测试落地页请求实体
 * Created by jzl on 18/5/19.
 */
public class ReqPromoteTestAuditQuery {
    //创建时间
    private String            createStartDate;

    private String            createEndDate;

    //Date格式的
    private Date              startDate;

    private Date              endDate;

    //广告ID集合
    private List<Long>        advertIds;

    //落地页地址
    private String            promoteUrl;

    //状态 null不限 0审核中 1通过 2拒绝
    private Integer           status;

    //开始行
    private Integer           rowStart;

    //查询几行
    private Integer           pageSize;

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getCreateStartDate() {
        return createStartDate;
    }

    public void setCreateStartDate(String createStartDate) {
        this.createStartDate = createStartDate;
    }

    public String getCreateEndDate() {
        return createEndDate;
    }

    public void setCreateEndDate(String createEndDate) {
        this.createEndDate = createEndDate;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getRowStart() {
        return rowStart;
    }

    public void setRowStart(Integer rowStart) {
        this.rowStart = rowStart;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}

==> tuia-advert-center-api-2.5.21-sources.jar: cn/com/duiba/tuia/core/api/dto/req/ReqPromoteTestAuditQuery.java <==
package cn.com.duiba.tuia.core.api.dto.req;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**查询测试落地页请求实体
 * Created by jzl on 18/5/19.
 */
public class ReqPromoteTestAuditQuery  implements Serializable {
    private static final long serialVersionUID = -8873879688248302893L;
    //创建时间
    private String            createStartDate;

    private String            createEndDate;

    //Date格式的
    private Date              startDate;

    private Date              endDate;

    //广告ID集合
    private List<Long>        advertIds;

    //落地页地址
    private String            promoteUrl;

    //状态 null不限 0审核中 1通过 2拒绝
    private Integer           status;

    //开始行
    private Integer           rowStart;

    //查询几行
    private Integer           pageSize;
    //落地页id
    private Long promoteId;

    //落地页名称
    private String promoteName;

    public Long getPromoteId() {
        return promoteId;
    }

    public void setPromoteId(Long promoteId) {
        this.promoteId = promoteId;
    }

    public String getPromoteName() {
        return promoteName;
    }

    public void setPromoteName(String promoteName) {
        this.promoteName = promoteName;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getCreateStartDate() {
        return createStartDate;
    }

    public void setCreateStartDate(String createStartDate) {
        this.createStartDate = createStartDate;
    }

    public String getCreateEndDate() {
        return createEndDate;
    }

    public void setCreateEndDate(String createEndDate) {
        this.createEndDate = createEndDate;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getRowStart() {
        return rowStart;
    }

    public void setRowStart(Integer rowStart) {
        this.rowStart = rowStart;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}
